"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var twemoji_1 = __importDefault(require("twemoji"));
var emoji_lib_json_1 = __importDefault(require("./lib/emoji-lib.json"));
/**
 * Parse text with emoji support
 * @return {string}
 */
var uEmojiParser = {
    emojiLibJson: emoji_lib_json_1["default"],
    getEmojiObjectByCode: function (emojiCode) {
        emojiCode = emojiCode.replace(/:/g, '');
        if (uEmojiParser.emojiLibJson[emojiCode] && typeof uEmojiParser.emojiLibJson[emojiCode] === 'object' && uEmojiParser.emojiLibJson[emojiCode].char) {
            return uEmojiParser.emojiLibJson[emojiCode];
        }
        else {
            var emojiKey = Object.keys(uEmojiParser.emojiLibJson).find(function (emojiKey) { return uEmojiParser.emojiLibJson[emojiKey].keywords.includes(emojiCode); });
            if (!!emojiKey) {
                return uEmojiParser.emojiLibJson[emojiKey];
            }
        }
        return undefined;
    },
    parse: function (text) {
        var _this = this;
        if (typeof text !== 'string') {
            throw new Error('The text parameter should be a string.');
        }
        var emojisRegExp = /:(\w+):/g;
        var emojisList = text.match(emojisRegExp);
        if (emojisList) {
            emojisList.forEach(function (emojiCode) {
                var emoji = _this.getEmojiObjectByCode(emojiCode);
                if (emoji) {
                    var regEx = new RegExp(emojiCode);
                    text = text.replace(regEx, emoji.char);
                }
            });
        }
        return twemoji_1["default"].parse(text);
    }
};
module.exports = uEmojiParser;
//# sourceMappingURL=main.js.map